
function AimWindowLoad2(topWindow)
{
	// Make it move to the Setup Tab not online tab
	var tabObj = topWindow.frames["AimSidebarPanel"].document.getElementById("tabOnline");
	
	tabObj.setAttribute("style","");
	tabObj.setAttribute("selected","false");

	tabObj = topWindow.frames["AimSidebarPanel"].document.getElementById("tabSetup");
	//tabObj.setAttribute("style","text-decoration:underline;");
	tabObj.setAttribute("selected","true");

	//tabObj.click();

	var tabPanel = topWindow.frames["AimSidebarPanel"].document.getElementById("OnlineOrgTabPanel");
	tabPanel.setAttribute("selectedIndex",1);

	var parentState = topWindow.document.getElementById("AimSidebarState");
	if(!parentState)
		return;

	dump("got parent State\n");
	parentState.setAttribute("AimSidebarTab", "Setup"); 
}
